@@ -452,8 +452,6 @@ add_addressbook_sources (EAccount *account, GSList *folders)
 		e_source_set_property (source, "offline_sync", 
 					       camel_url_get_param (url, "offline_sync") ? "1" : "0");
 		e_source_set_property (source, "completion", "true");
-		if (folder->is_default) 
-			e_source_set_property (source, "delete", "no");
 		e_source_group_add_source (group, source, -1);
 		g_object_unref (source);
 	}
@@ -464,6 +462,7 @@ add_addressbook_sources (EAccount *account, GSList *folders)
 
 		uri = g_strdup_printf("mapigal://%s@%s/;Global Address List", url->user, url->host);
 		source = e_source_new_with_absolute_uri ("Global Address List", uri);
+		g_free (uri);
 		// source = e_source_new ("Global Address List", g_strconcat (";","Global Address List" , NULL));
 		e_source_set_property (source, "auth", "plain/password");
 		e_source_set_property (source, "auth-domain", "MAPIGAL");
@@ -478,7 +477,6 @@ add_addressbook_sources (EAccount *account, GSList *folders)
 		// camel_url_get_param (url, "offline_sync") ? "1" : "0");
 		e_source_set_property(source, "offline_sync", "1");
 		e_source_set_property (source, "completion", "true");
-		e_source_set_property (source, "delete", "no");
 		e_source_group_add_source (group, source, -1);
 		g_object_unref (source);
 	}
